#
# PySNMP MIB module FRSLD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FRSLD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( DLCI, ) = mibBuilder.importSymbols("FRAME-RELAY-DTE-MIB", "DLCI")
( CounterBasedGauge64, ) = mibBuilder.importSymbols("HCNUM-TC", "CounterBasedGauge64")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( ModuleIdentity, TimeTicks, Bits, Unsigned32, Counter32, mib_2, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, Gauge32, Counter64, IpAddress, iso, NotificationType, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "TimeTicks", "Bits", "Unsigned32", "Counter32", "mib-2", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "Gauge32", "Counter64", "IpAddress", "iso", "NotificationType", "MibIdentifier")
( TextualConvention, RowStatus, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "RowStatus", "DisplayString", "TimeStamp")
frsldMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 95)).setRevisions(("2002-01-03 00:00",))
if mibBuilder.loadTexts: frsldMIB.setLastUpdated('200201030000Z')
if mibBuilder.loadTexts: frsldMIB.setOrganization('IETF Frame Relay Service MIB Working Group')
if mibBuilder.loadTexts: frsldMIB.setContactInfo('IETF Frame Relay Service MIB (frnetmib) Working Group\n\n           WG Charter:    http://www.ietf.org/html.charters/\n                                 frnetmib-charter.html\n           WG-email:      frnetmib@sunroof.eng.sun.com\n           Subscribe:     frnetmib-request@sunroof.eng.sun.com\n           Email Archive: ftp://ftp.ietf.org/ietf-mail-archive/frnetmib\n\n           Chair:      Andy Malis\n                       Vivace Networks\n           Email:      Andy.Malis@vivacenetworks.com\n\n           WG editor:  Robert Steinberger\n                       Paradyne Networks and\n                       Fujitsu Network Communications\n           Email:      robert.steinberger@fnc.fujitsu.com\n\n           Co-author:  Orly Nicklass\n                       RAD Data Communications Ltd.\n           EMail:      Orly_n@rad.co.il')
if mibBuilder.loadTexts: frsldMIB.setDescription('The MIB module to describe generic objects for\n             FRF.13 Frame Relay Service Level Definitions.')
class FrsldTxRP(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("srcLocalRP", 1), ("ingTxLocalRP", 2), ("tpTxLocalRP", 3), ("eqiTxLocalRP", 4), ("eqoTxLocalRP", 5), ("otherTxLocalRP", 6), ("srcRemoteRP", 7), ("ingTxRemoteRP", 8), ("tpTxRemoteRP", 9), ("eqiTxRemoteRP", 10), ("eqoTxRemoteRP", 11), ("otherTxRemoteRP", 12),)

class FrsldRxRP(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("desLocalRP", 1), ("ingRxLocalRP", 2), ("tpRxLocalRP", 3), ("eqiRxLocalRP", 4), ("eqoRxLocalRP", 5), ("otherRxLocalRP", 6), ("desRemoteRP", 7), ("ingRxRemoteRP", 8), ("tpRxRemoteRP", 9), ("eqiRxRemoteRP", 10), ("eqoRxRemoteRP", 11), ("otherRxRemoteRP", 12),)

frsldObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 1))
frsldCapabilities = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 2))
frsldConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3))
frsldPvcCtrlTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 1), )
if mibBuilder.loadTexts: frsldPvcCtrlTable.setDescription('The Frame Relay Service Level Definitions\n             PVC control table.')
frsldPvcCtrlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"))
if mibBuilder.loadTexts: frsldPvcCtrlEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions PVC control table.')
frsldPvcCtrlDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 1), DLCI())
if mibBuilder.loadTexts: frsldPvcCtrlDlci.setDescription('The value of this object is equal to the DLCI\n             value for this PVC.')
frsldPvcCtrlTransmitRP = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 2), FrsldTxRP())
if mibBuilder.loadTexts: frsldPvcCtrlTransmitRP.setDescription('The reference point this PVC uses for calculation\n             of transmitter related statistics.  This object\n             together with frsldPvcCtrlReceiveRP define the\n             measurement domain.')
frsldPvcCtrlReceiveRP = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 3), FrsldRxRP())
if mibBuilder.loadTexts: frsldPvcCtrlReceiveRP.setDescription('The reference point this PVC uses for calculation\n             of receiver related statistics.  This object\n             together with frsldPvcCtrlTransmitRP define the\n             measurement domain.')
frsldPvcCtrlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlStatus.setDescription('The status of the current row.  This object is\n             used to add, delete, and disable rows in this\n             table.  When the status changes to active(1) for the\n             first time, a row will also be added to the data\n             table below.  This row SHOULD not be removed until\n             the status is changed to deleted.\n\n             When this object is set to destroy(6), all associated\n             sample and data table rows will also be deleted.\n             When this object is changed from active(1) to any\n             other valid value, the defined purge behavior will\n             affect the data and sample tables.\n\n             The rows added to this table MUST have a valid\n             ifIndex and an ifType related to frame relay.  Further,\n             the reference points referred to by frsldPvcCtrlTransmitRP\n             and frsldPvcCtrlReceiveRP MUST be supported (see the\n             frsldRPCaps object).\n\n             If at any point the row is not in the active(1) state\n             and the DLCI no longer exists, the state SHOULD\n             report notReady(3).\n\n             The data in this table SHOULD persist through power\n             cycles.  The symantics of readiness for the rows still\n             applies.  This means that it is possible for a row to be\n             reprovisioned as notReady(3) if the underlying DLCI does\n             not persist.')
frsldPvcCtrlPacketFreq = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3600)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlPacketFreq.setDescription('The frequency in seconds between initiation of\n             specialized packets used to collect delay and / or\n             delivery information as supported by the device.\n             A value of zero indicates that no packets will\n             be sent.')
frsldPvcCtrlDelayFrSize = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,8188)).clone(128)).setUnits('octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayFrSize.setDescription('The size of the payload in the frame used for\n             calculation of network delay.')
frsldPvcCtrlDelayType = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("oneWay", 1), ("roundTrip", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayType.setDescription('The type of delay measurement performed.')
frsldPvcCtrlDelayTimeOut = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,3600)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDelayTimeOut.setDescription('A delay frame will count as a missed poll if\n             it is not updated in the time specified by\n             frsldPvcCtrlDelayTimeOut.')
frsldPvcCtrlPurge = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,172800))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlPurge.setDescription('This object defines the amount of time the device\n             will wait, after discovering that a DLCI does not exist,\n             the DLCI was deleted or the value of frsldPvcCtrlStatus\n             changes from active(1) to either notInService(2) or\n             notReady(3), prior to automatically purging the history\n             in the sample tables and resetting the data in the data\n             tables to all zeroes.  If frsldPvcCtrlStatus is manually\n             set to destroy(6), this object does not apply.')
frsldPvcCtrlDeleteOnPurge = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("sampleContols", 2), ("all", 3),)).clone('all')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldPvcCtrlDeleteOnPurge.setDescription('This object defines whether rows will\n             automatically be deleted from the tables\n             when the information is purged.\n\n             - A value of none(1) indicates that no rows\n               will deleted.  The last known values will\n               be preserved.\n             - A value of sampleControls(2) indicates\n               that all associated sample control rows\n               will be deleted.\n             - A value of all(3) indicates that all\n               associated rows SHOULD be deleted.')
frsldPvcCtrlLastPurgeTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 1, 1, 11), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcCtrlLastPurgeTime.setDescription('This object returns the value of sysUpTime\n             at the time the information was last purged.\n             This value SHOULD be set to the sysUpTime\n             upon setting frsldPvcCtrlStatus to active(1)\n             for the first time.  Each time a\n             discontinuity in the counters occurs, this\n             value MUST be set to the sysUpTime.\n\n             If frsldPvcCtrlStatus has never been active(1),\n             this object SHOULD return 0.\n\n             This object SHOULD be used as the discontinuity\n             timer for the counters in frsldPvcDataTable.')
frsldSmplCtrlTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 2), )
if mibBuilder.loadTexts: frsldSmplCtrlTable.setDescription('The Frame Relay Service Level Definitions\n             sampling control table.')
frsldSmplCtrlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"), (0, "FRSLD-MIB", "frsldSmplCtrlIdx"))
if mibBuilder.loadTexts: frsldSmplCtrlEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions sample control table.')
frsldSmplCtrlIdx = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,256)))
if mibBuilder.loadTexts: frsldSmplCtrlIdx.setDescription('The unique index for this row in the\n             sample control table.')
frsldSmplCtrlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlStatus.setDescription('The status of the current row.  This object is\n             used to add, delete, and disable rows in this\n             table.  This row SHOULD NOT be removed until the\n             status is changed to destroy(6).  When the status\n             changes to active(1), the collection in the sample\n             tables below will be activated.\n\n             The rows added to this table MUST have a valid\n             ifIndex, an ifType related to frame relay,\n             frsldPvcCtrlDlci MUST exist for the specified\n             ifIndex and frsldPvcCtrlStatus MUST have a\n             value of active(1).\n\n             The value of frsldPvcCtrlStatus MUST be active(1)\n             to transition this object to active(1).  If\n             the value of frsldPvcCtrlStatus becomes anything\n             other than active(1) when the state of this object\n             is not active(1), this object SHOULD be set to\n             notReady(3).\n\n             The data in this table SHOULD persist through power\n             cycles.  The symantics of readiness for the rows still\n             applies.  This means that it is possible for a row to be\n             reprovisioned as notReady(3) if the underlying DLCI does\n             not persist.')
frsldSmplCtrlColPeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlColPeriod.setDescription('The amount of time in seconds that defines a\n             period of collection for the statistics.\n             At the end of each period, the statistics will be\n             sampled and a row is added to the sample table.')
frsldSmplCtrlBuckets = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(60)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frsldSmplCtrlBuckets.setDescription('The number of discrete buckets over which the\n             data statistics are sampled.\n\n             When this object is created or modified, the device\n             SHOULD attempt to set the frsldSmplCtrlBuckets-\n             Granted to a value as close as is possible\n             depending upon the implementation and the available\n             resources.')
frsldSmplCtrlBucketsGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldSmplCtrlBucketsGranted.setDescription('The number of discrete buckets granted.  This\n             object will return 0 until frsldSmplCtrlStatus is\n             set to active(1).  At that time the buckets will be\n             allocated depending upon implementation and\n             available resources.')
frsldPvcDataTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 3), )
if mibBuilder.loadTexts: frsldPvcDataTable.setDescription('The Frame Relay Service Level Definitions\n             data table.\n\n             This table contains accumulated values of the\n             collected data.  It is the table that should be\n             referenced by external polling mechanisms if\n             time based polling be desired.')
frsldPvcDataEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"))
if mibBuilder.loadTexts: frsldPvcDataEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions data table.')
frsldPvcDataMissedPolls = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataMissedPolls.setDescription('The total number of polls that have been determined\n             to be missed.  These polls are typically associated\n             with the calculation of delay but may also be\n             used for the calculation of other statistics.  If an\n             anticipated poll is not received in a reasonable\n             amount of time, it should be counted as missed.\n             The value used to determine the reasonable amount\n             of time is contained in frsldPvcCtrlDelayTimeOut.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 10), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.  This object is a 64-bit version\n             of frsldPvcDataFrDeliveredC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 11), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.  This object is a 64-bit\n             version of frsldPvcDataFrDeliveredE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 12), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR.  This object is\n             a 64-bit version of frsldPvcDataFrOfferedC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 13), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.  This\n             object is a 64-bit version of frsldPvcDataFrOfferedE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 14), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR.  This object is a 64-bit version of\n             frsldPvcDataDataDeliveredC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 15), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR.  This object is a 64-bit\n             version of frsldPvcDataDataDeliveredE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 16), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR.  This object is\n             a 64-bit version of frsldPvcDataDataOfferedC.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataHCDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 17), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataHCDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR.\n             This object is a 64-bit version of\n             frsldPvcDataDataOfferedE.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcDataUnavailableTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 18), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataUnavailableTime.setDescription('The amount of time this PVC was declared unavailable\n             for any reason since this row was created.')
frsldPvcDataUnavailables = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 3, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcDataUnavailables.setDescription('The number of times this PVC was declared unavailable\n             for any reason since this row was created.\n\n             Discontinuities in the value of this counter can\n             occur at re-initialization of the management system\n             and at other times as indicated by\n             frsldPvcCtrlLastPurgeTime.')
frsldPvcSampleTable = MibTable((1, 3, 6, 1, 2, 1, 95, 1, 4), )
if mibBuilder.loadTexts: frsldPvcSampleTable.setDescription('The Frame Relay Service Level Definitions\n             sample table.')
frsldPvcSampleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 95, 1, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRSLD-MIB", "frsldPvcCtrlDlci"), (0, "FRSLD-MIB", "frsldPvcCtrlTransmitRP"), (0, "FRSLD-MIB", "frsldPvcCtrlReceiveRP"), (0, "FRSLD-MIB", "frsldSmplCtrlIdx"), (0, "FRSLD-MIB", "frsldPvcSmplIdx"))
if mibBuilder.loadTexts: frsldPvcSampleEntry.setDescription('An entry in the Frame Relay Service Level\n             Definitions data sample table.')
frsldPvcSmplIdx = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: frsldPvcSmplIdx.setDescription('The bucket index of the current sample.  This\n             increments once for each new bucket in the\n             table.')
frsldPvcSmplDelayMin = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 2), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayMin.setDescription('The minimum delay reported in microseconds measured\n             for any information packet that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplDelayMax = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 3), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayMax.setDescription('The largest delay reported in microseconds measured\n             for any information packet that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplDelayAvg = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 4), Gauge32()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDelayAvg.setDescription('The average delay reported in microseconds measured\n             for all delay packets that arrived during this\n             interval.\n\n             A value of zero means that no data is available.')
frsldPvcSmplMissedPolls = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplMissedPolls.setDescription('The total number of polls that were missed during\n             this interval.')
frsldPvcSmplFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrDeliveredC.')
frsldPvcSmplFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrDeliveredE.')
frsldPvcSmplFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrOfferedC.')
frsldPvcSmplFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCFrOfferedE.')
frsldPvcSmplDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 10), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataDeliveredC.')
frsldPvcSmplDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 11), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlDeliveredRP and determined to have been\n             sent in excess of the CIR during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataDeliveredE.')
frsldPvcSmplDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 12), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataOfferedC.setDescription('The number of octets that were offered through\n\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataOfferredC.')
frsldPvcSmplDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.\n\n             If it is the case that the high capacity counters\n             are also used, this MUST report the value of the\n             lower 32 bits of the CounterBasedGauge64 value of\n             frsldPvcSmplHCDataOfferedE.')
frsldPvcSmplHCFrDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 14), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrDeliveredC.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.  This object\n             is a 64-bit version of frsldPvcSmplFrDeliveredC.')
frsldPvcSmplHCFrDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 15), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrDeliveredE.setDescription('The number of frames that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n\n             sent in excess of the CIR during this interval.\n             This object is a 64-bit version of frsldPvcSmpl-\n             FrDeliveredE.')
frsldPvcSmplHCFrOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 16), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrOfferedC.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.  This object is a 64-bit version of\n             frsldPvcSmplFrOfferedC.')
frsldPvcSmplHCFrOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 17), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCFrOfferedE.setDescription('The number of frames that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.  This object is a 64-bit\n             version of frsldPvcSmplFrOfferedE.')
frsldPvcSmplHCDataDeliveredC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 18), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataDeliveredC.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent within CIR during this interval.  This value\n             is a 64-bit version of frsldPvcSmplDataDeliveredC.')
frsldPvcSmplHCDataDeliveredE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 19), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataDeliveredE.setDescription('The number of octets that were received at\n             frsldPvcCtrlReceiveRP and determined to have been\n             sent in excess of the CIR during this interval.  This\n             value is a 64-bit version of frsldPvcSmplData-\n             DeliveredE.')
frsldPvcSmplHCDataOfferedC = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 20), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataOfferedC.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP within CIR during this\n             interval.  This value is a 64-bit version of\n             frsldPvcSmplDataOfferedC.')
frsldPvcSmplHCDataOfferedE = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 21), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplHCDataOfferedE.setDescription('The number of octets that were offered through\n             frsldPvcCtrlTransmitRP in excess of the CIR\n             during this interval.  This object is a 64-bit\n             version of frsldPvcSmplDataOfferedE.')
frsldPvcSmplUnavailableTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 22), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplUnavailableTime.setDescription('The amount of time this PVC was declared\n             unavailable for any reason during this interval.')
frsldPvcSmplUnavailables = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 23), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplUnavailables.setDescription('The number of times this PVC was declared\n             unavailable for any reason during this interval.')
frsldPvcSmplStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 24), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplStartTime.setDescription('The value of sysUpTime when this sample interval\n             started.')
frsldPvcSmplEndTime = MibTableColumn((1, 3, 6, 1, 2, 1, 95, 1, 4, 1, 25), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcSmplEndTime.setDescription('The value of sysUpTime when this sample interval\n             ended.  No data will be reported and the row will\n             not appear in the table until the sample has\n             been collected.')
frsldPvcCtrlWriteCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 1), Bits().clone(namedValues=NamedValues(("frsldPvcCtrlStatus", 0), ("frsldPvcCtrlPacketFreq", 1), ("frsldPvcCtrlDelayFrSize", 2), ("frsldPvcCtrlDelayType", 3), ("frsldPvcCtrlDelayTimeOut", 4), ("frsldPvcCtrlPurge", 5), ("frsldPvcCtrlDeleteOnPurge", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldPvcCtrlWriteCaps.setDescription('This object specifies the write capabilities\n             for the read-create objects of the PVC Control\n             table.  If the corresponding bit is enabled (1),\n             the agent supports writes to that object.')
frsldSmplCtrlWriteCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 2), Bits().clone(namedValues=NamedValues(("frsldSmplCtrlStatus", 0), ("frsldSmplCtrlBuckets", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldSmplCtrlWriteCaps.setDescription('This object specifies the write capabilities\n             for the read-create objects of the Sample Control\n             table.  If the corresponding bit is enabled (1),\n             the agent supports writes to that object.')
frsldRPCaps = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 3), Bits().clone(namedValues=NamedValues(("srcLocalRP", 0), ("ingTxLocalRP", 1), ("tpTxLocalRP", 2), ("eqiTxLocalRP", 3), ("eqoTxLocalRP", 4), ("otherTxLocalRP", 5), ("srcRemoteRP", 6), ("ingTxRemoteRP", 7), ("tpTxRemoteRP", 8), ("eqiTxRemoteRP", 9), ("eqoTxRemoteRP", 10), ("otherTxRemoteRP", 11), ("desLocalRP", 12), ("ingRxLocalRP", 13), ("tpRxLocalRP", 14), ("eqiRxLocalRP", 15), ("eqoRxLocalRP", 16), ("otherRxLocalRP", 17), ("desRemoteRP", 18), ("ingRxRemoteRP", 19), ("tpRxRemoteRP", 20), ("eqiRxRemoteRP", 21), ("eqoRxRemoteRP", 22), ("otherRxRemoteRP", 23),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldRPCaps.setDescription('This object specifies the reference points that\n             the agent supports.  This object allows the management\n             application to discover which rows can be created on\n             a specific device.')
frsldMaxPvcCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frsldMaxPvcCtrls.setDescription('The maximum number of control rows that can be created\n             in frsldPvcCtrlTable.  Sets to this object lower than\n             the current value of frsldNumPvcCtrls should result in\n             inconsistentValue.')
frsldNumPvcCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldNumPvcCtrls.setDescription('The current number of rows in frsldPvcCtrlTable.')
frsldMaxSmplCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frsldMaxSmplCtrls.setDescription('The maximum number of control rows that can be created\n             in frsldSmplCtrlTable.  Sets to this object lower than\n             the current value of frsldNumSmplCtrls should result in\n             inconsistentValue.')
frsldNumSmplCtrls = MibScalar((1, 3, 6, 1, 2, 1, 95, 2, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frsldNumSmplCtrls.setDescription('The current number of rows in frsldSmplCtrlTable.')
frsldMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3, 1))
frsldMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 95, 3, 2))
frsldCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 95, 3, 2, 1)).setObjects(*(("FRSLD-MIB", "frsldPvcReqCtrlGroup"), ("FRSLD-MIB", "frsldPvcReqDataGroup"), ("FRSLD-MIB", "frsldCapabilitiesGroup"), ("FRSLD-MIB", "frsldPvcHCFrameDataGroup"), ("FRSLD-MIB", "frsldPvcHCOctetDataGroup"), ("FRSLD-MIB", "frsldPvcPacketGroup"), ("FRSLD-MIB", "frsldPvcDelayCtrlGroup"), ("FRSLD-MIB", "frsldPvcSampleCtrlGroup"), ("FRSLD-MIB", "frsldPvcDelayDataGroup"), ("FRSLD-MIB", "frsldPvcSampleDelayGroup"), ("FRSLD-MIB", "frsldPvcSampleDataGroup"), ("FRSLD-MIB", "frsldPvcSampleHCFrameGroup"), ("FRSLD-MIB", "frsldPvcSampleHCDataGroup"), ("FRSLD-MIB", "frsldPvcSampleAvailGroup"), ("FRSLD-MIB", "frsldPvcSampleGeneralGroup"),))
if mibBuilder.loadTexts: frsldCompliance.setDescription('The compliance statement for SNMP entities\n             which support with Frame Relay Service Level\n             Definitions.  This group defines the minimum\n             level of support required for compliance.')
frsldPvcReqCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 1)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlStatus"), ("FRSLD-MIB", "frsldPvcCtrlPurge"), ("FRSLD-MIB", "frsldPvcCtrlDeleteOnPurge"), ("FRSLD-MIB", "frsldPvcCtrlLastPurgeTime"),))
if mibBuilder.loadTexts: frsldPvcReqCtrlGroup.setDescription('A collection of required objects providing\n            control information applicable to a PVC which\n            implements Service Level Definitions.')
frsldPvcPacketGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 2)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlPacketFreq"),))
if mibBuilder.loadTexts: frsldPvcPacketGroup.setDescription('A collection of optional objects providing packet\n            level control information applicable to a PVC which\n            implements Service Level Definitions.')
frsldPvcDelayCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 3)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlDelayFrSize"), ("FRSLD-MIB", "frsldPvcCtrlDelayType"), ("FRSLD-MIB", "frsldPvcCtrlDelayTimeOut"),))
if mibBuilder.loadTexts: frsldPvcDelayCtrlGroup.setDescription('A collection of optional objects providing delay\n            control information applicable to a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcPacketGroup\n            and frsldPvcDelayDataGroup MUST also be implemented.')
frsldPvcSampleCtrlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 4)).setObjects(*(("FRSLD-MIB", "frsldSmplCtrlStatus"), ("FRSLD-MIB", "frsldSmplCtrlColPeriod"), ("FRSLD-MIB", "frsldSmplCtrlBuckets"), ("FRSLD-MIB", "frsldSmplCtrlBucketsGranted"),))
if mibBuilder.loadTexts: frsldPvcSampleCtrlGroup.setDescription('A collection of optional objects providing sample\n            control information applicable to a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            and frsldPvcSampleGeneralGroup MUST also be\n            implemented.')
frsldPvcReqDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 5)).setObjects(*(("FRSLD-MIB", "frsldPvcDataFrDeliveredC"), ("FRSLD-MIB", "frsldPvcDataFrDeliveredE"), ("FRSLD-MIB", "frsldPvcDataFrOfferedC"), ("FRSLD-MIB", "frsldPvcDataFrOfferedE"), ("FRSLD-MIB", "frsldPvcDataDataDeliveredC"), ("FRSLD-MIB", "frsldPvcDataDataDeliveredE"), ("FRSLD-MIB", "frsldPvcDataDataOfferedC"), ("FRSLD-MIB", "frsldPvcDataDataOfferedE"), ("FRSLD-MIB", "frsldPvcDataUnavailableTime"), ("FRSLD-MIB", "frsldPvcDataUnavailables"),))
if mibBuilder.loadTexts: frsldPvcReqDataGroup.setDescription('A collection of required objects providing data\n            collected on a PVC which implements Service\n            Level Definitions.')
frsldPvcDelayDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 6)).setObjects(*(("FRSLD-MIB", "frsldPvcDataMissedPolls"),))
if mibBuilder.loadTexts: frsldPvcDelayDataGroup.setDescription('A collection of optional objects providing delay\n            data collected on a PVC which implements Service\n            Level Definitions.\n\n            If this group is implemented, frsldPvcDelayCtrlGroup\n            MUST also be implemented.')
frsldPvcHCFrameDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 7)).setObjects(*(("FRSLD-MIB", "frsldPvcDataHCFrDeliveredC"), ("FRSLD-MIB", "frsldPvcDataHCFrDeliveredE"), ("FRSLD-MIB", "frsldPvcDataHCFrOfferedC"), ("FRSLD-MIB", "frsldPvcDataHCFrOfferedE"),))
if mibBuilder.loadTexts: frsldPvcHCFrameDataGroup.setDescription('A collection of optional objects providing high\n            capacity frame data collected on a PVC which\n            implements Service Level Definitions.')
frsldPvcHCOctetDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 8)).setObjects(*(("FRSLD-MIB", "frsldPvcDataHCDataDeliveredC"), ("FRSLD-MIB", "frsldPvcDataHCDataDeliveredE"), ("FRSLD-MIB", "frsldPvcDataHCDataOfferedC"), ("FRSLD-MIB", "frsldPvcDataHCDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcHCOctetDataGroup.setDescription('A collection of optional objects providing high\n            capacity octet data collected on a PVC which\n            implements Service Level Definitions.')
frsldPvcSampleDelayGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 9)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplDelayMin"), ("FRSLD-MIB", "frsldPvcSmplDelayMax"), ("FRSLD-MIB", "frsldPvcSmplDelayAvg"), ("FRSLD-MIB", "frsldPvcSmplMissedPolls"),))
if mibBuilder.loadTexts: frsldPvcSampleDelayGroup.setDescription('A collection of optional objects providing delay\n            sample data collected on a PVC which implements\n            Service Level Definitions.\n\n            If this group is implemented, frsldPvcDelayCtrlGroup\n            MUST also be implemented.')
frsldPvcSampleDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 10)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplFrDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplFrDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplFrOfferedC"), ("FRSLD-MIB", "frsldPvcSmplFrOfferedE"), ("FRSLD-MIB", "frsldPvcSmplDataDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplDataDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplDataOfferedC"), ("FRSLD-MIB", "frsldPvcSmplDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleDataGroup.setDescription('A collection of optional objects providing data\n            and frame delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            MUST also be implemented.')
frsldPvcSampleHCFrameGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 11)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplHCFrDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplHCFrDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplHCFrOfferedC"), ("FRSLD-MIB", "frsldPvcSmplHCFrOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleHCFrameGroup.setDescription('A collection of optional objects providing high\n            capacity frame delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcHCFrameDataGroup\n            MUST also be implemented.')
frsldPvcSampleHCDataGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 12)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplHCDataDeliveredC"), ("FRSLD-MIB", "frsldPvcSmplHCDataDeliveredE"), ("FRSLD-MIB", "frsldPvcSmplHCDataOfferedC"), ("FRSLD-MIB", "frsldPvcSmplHCDataOfferedE"),))
if mibBuilder.loadTexts: frsldPvcSampleHCDataGroup.setDescription('A collection of optional objects providing high\n            capacity data delivery sample data collected on a PVC\n            which implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcHCOctetDataGroup\n\n            MUST also be implemented.')
frsldPvcSampleAvailGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 13)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplUnavailableTime"), ("FRSLD-MIB", "frsldPvcSmplUnavailables"),))
if mibBuilder.loadTexts: frsldPvcSampleAvailGroup.setDescription('A collection of optional objects providing\n            availability sample data collected on a PVC which\n            implements Service Level Definitions.\n\n            If this group is implemented, frsldPvcReqDataGroup\n            MUST also be implemented.')
frsldPvcSampleGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 14)).setObjects(*(("FRSLD-MIB", "frsldPvcSmplStartTime"), ("FRSLD-MIB", "frsldPvcSmplEndTime"),))
if mibBuilder.loadTexts: frsldPvcSampleGeneralGroup.setDescription('A collection of optional objects providing\n            general sample data collected on a PVC which\n            implements Service Level Definitions.')
frsldCapabilitiesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 95, 3, 1, 15)).setObjects(*(("FRSLD-MIB", "frsldPvcCtrlWriteCaps"), ("FRSLD-MIB", "frsldSmplCtrlWriteCaps"), ("FRSLD-MIB", "frsldRPCaps"), ("FRSLD-MIB", "frsldMaxPvcCtrls"), ("FRSLD-MIB", "frsldNumPvcCtrls"), ("FRSLD-MIB", "frsldMaxSmplCtrls"), ("FRSLD-MIB", "frsldNumSmplCtrls"),))
if mibBuilder.loadTexts: frsldCapabilitiesGroup.setDescription('A collection of required objects providing\n            capability information and control for this\n            MIB module.')
mibBuilder.exportSymbols("FRSLD-MIB", PYSNMP_MODULE_ID=frsldMIB, frsldPvcSampleDataGroup=frsldPvcSampleDataGroup, frsldCapabilitiesGroup=frsldCapabilitiesGroup, frsldPvcSmplMissedPolls=frsldPvcSmplMissedPolls, FrsldTxRP=FrsldTxRP, frsldPvcCtrlReceiveRP=frsldPvcCtrlReceiveRP, frsldMIB=frsldMIB, FrsldRxRP=FrsldRxRP, frsldPvcDataHCFrOfferedE=frsldPvcDataHCFrOfferedE, frsldPvcCtrlDeleteOnPurge=frsldPvcCtrlDeleteOnPurge, frsldMaxSmplCtrls=frsldMaxSmplCtrls, frsldPvcSmplFrOfferedE=frsldPvcSmplFrOfferedE, frsldPvcDataFrOfferedC=frsldPvcDataFrOfferedC, frsldPvcSmplHCFrOfferedE=frsldPvcSmplHCFrOfferedE, frsldPvcCtrlDlci=frsldPvcCtrlDlci, frsldPvcSmplEndTime=frsldPvcSmplEndTime, frsldCompliance=frsldCompliance, frsldMIBGroups=frsldMIBGroups, frsldPvcSmplDataDeliveredC=frsldPvcSmplDataDeliveredC, frsldPvcCtrlDelayTimeOut=frsldPvcCtrlDelayTimeOut, frsldPvcSampleGeneralGroup=frsldPvcSampleGeneralGroup, frsldPvcSmplFrDeliveredE=frsldPvcSmplFrDeliveredE, frsldPvcSmplUnavailables=frsldPvcSmplUnavailables, frsldPvcDataDataOfferedC=frsldPvcDataDataOfferedC, frsldPvcSmplHCDataDeliveredE=frsldPvcSmplHCDataDeliveredE, frsldPvcSmplStartTime=frsldPvcSmplStartTime, frsldPvcSmplUnavailableTime=frsldPvcSmplUnavailableTime, frsldPvcReqDataGroup=frsldPvcReqDataGroup, frsldCapabilities=frsldCapabilities, frsldPvcSmplDelayMin=frsldPvcSmplDelayMin, frsldPvcSmplDataOfferedC=frsldPvcSmplDataOfferedC, frsldRPCaps=frsldRPCaps, frsldPvcSmplDataOfferedE=frsldPvcSmplDataOfferedE, frsldPvcSampleTable=frsldPvcSampleTable, frsldPvcSmplDataDeliveredE=frsldPvcSmplDataDeliveredE, frsldSmplCtrlBuckets=frsldSmplCtrlBuckets, frsldNumSmplCtrls=frsldNumSmplCtrls, frsldObjects=frsldObjects, frsldPvcSmplDelayAvg=frsldPvcSmplDelayAvg, frsldPvcDataDataDeliveredC=frsldPvcDataDataDeliveredC, frsldPvcSmplDelayMax=frsldPvcSmplDelayMax, frsldPvcHCOctetDataGroup=frsldPvcHCOctetDataGroup, frsldPvcDataUnavailables=frsldPvcDataUnavailables, frsldPvcCtrlEntry=frsldPvcCtrlEntry, frsldPvcCtrlTable=frsldPvcCtrlTable, frsldPvcSmplHCDataOfferedC=frsldPvcSmplHCDataOfferedC, frsldPvcCtrlTransmitRP=frsldPvcCtrlTransmitRP, frsldPvcSmplFrDeliveredC=frsldPvcSmplFrDeliveredC, frsldPvcDataFrDeliveredC=frsldPvcDataFrDeliveredC, frsldSmplCtrlStatus=frsldSmplCtrlStatus, frsldPvcSampleAvailGroup=frsldPvcSampleAvailGroup, frsldPvcCtrlWriteCaps=frsldPvcCtrlWriteCaps, frsldPvcDelayCtrlGroup=frsldPvcDelayCtrlGroup, frsldPvcCtrlDelayFrSize=frsldPvcCtrlDelayFrSize, frsldPvcCtrlLastPurgeTime=frsldPvcCtrlLastPurgeTime, frsldPvcDataHCDataDeliveredE=frsldPvcDataHCDataDeliveredE, frsldPvcDataTable=frsldPvcDataTable, frsldPvcDataFrOfferedE=frsldPvcDataFrOfferedE, frsldPvcDataHCDataDeliveredC=frsldPvcDataHCDataDeliveredC, frsldSmplCtrlBucketsGranted=frsldSmplCtrlBucketsGranted, frsldSmplCtrlWriteCaps=frsldSmplCtrlWriteCaps, frsldPvcPacketGroup=frsldPvcPacketGroup, frsldMIBCompliances=frsldMIBCompliances, frsldSmplCtrlColPeriod=frsldSmplCtrlColPeriod, frsldSmplCtrlIdx=frsldSmplCtrlIdx, frsldPvcSmplFrOfferedC=frsldPvcSmplFrOfferedC, frsldConformance=frsldConformance, frsldSmplCtrlTable=frsldSmplCtrlTable, frsldPvcCtrlStatus=frsldPvcCtrlStatus, frsldPvcHCFrameDataGroup=frsldPvcHCFrameDataGroup, frsldPvcSmplHCFrOfferedC=frsldPvcSmplHCFrOfferedC, frsldNumPvcCtrls=frsldNumPvcCtrls, frsldPvcSmplHCFrDeliveredE=frsldPvcSmplHCFrDeliveredE, frsldPvcDataDataOfferedE=frsldPvcDataDataOfferedE, frsldPvcCtrlPurge=frsldPvcCtrlPurge, frsldPvcSmplHCFrDeliveredC=frsldPvcSmplHCFrDeliveredC, frsldPvcDataHCFrOfferedC=frsldPvcDataHCFrOfferedC, frsldPvcDataHCDataOfferedE=frsldPvcDataHCDataOfferedE, frsldPvcSmplIdx=frsldPvcSmplIdx, frsldPvcSampleHCDataGroup=frsldPvcSampleHCDataGroup, frsldPvcDataDataDeliveredE=frsldPvcDataDataDeliveredE, frsldPvcSampleCtrlGroup=frsldPvcSampleCtrlGroup, frsldPvcDelayDataGroup=frsldPvcDelayDataGroup, frsldPvcSampleDelayGroup=frsldPvcSampleDelayGroup, frsldPvcDataMissedPolls=frsldPvcDataMissedPolls, frsldMaxPvcCtrls=frsldMaxPvcCtrls, frsldPvcSmplHCDataDeliveredC=frsldPvcSmplHCDataDeliveredC, frsldPvcCtrlDelayType=frsldPvcCtrlDelayType, frsldPvcDataHCFrDeliveredC=frsldPvcDataHCFrDeliveredC, frsldPvcDataUnavailableTime=frsldPvcDataUnavailableTime, frsldPvcDataHCDataOfferedC=frsldPvcDataHCDataOfferedC, frsldPvcDataEntry=frsldPvcDataEntry, frsldPvcSampleHCFrameGroup=frsldPvcSampleHCFrameGroup, frsldPvcDataFrDeliveredE=frsldPvcDataFrDeliveredE, frsldPvcReqCtrlGroup=frsldPvcReqCtrlGroup, frsldPvcDataHCFrDeliveredE=frsldPvcDataHCFrDeliveredE, frsldPvcSmplHCDataOfferedE=frsldPvcSmplHCDataOfferedE, frsldSmplCtrlEntry=frsldSmplCtrlEntry, frsldPvcCtrlPacketFreq=frsldPvcCtrlPacketFreq, frsldPvcSampleEntry=frsldPvcSampleEntry)



#
# PySNMP MIB module TE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/TE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:31:21 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ValueRangeConstraint")
( TeHopAddress, MplsBitRate, TeHopAddressType, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "TeHopAddress", "MplsBitRate", "TeHopAddressType")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( TimeTicks, NotificationType, iso, ObjectIdentity, MibIdentifier, Bits, IpAddress, mib_2, Unsigned32, ModuleIdentity, Counter32, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "NotificationType", "iso", "ObjectIdentity", "MibIdentifier", "Bits", "IpAddress", "mib-2", "Unsigned32", "ModuleIdentity", "Counter32", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "Integer32")
( TextualConvention, StorageType, TimeStamp, DisplayString, TruthValue, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "StorageType", "TimeStamp", "DisplayString", "TruthValue", "RowStatus")
teMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 122)).setRevisions(("2005-01-04 00:00",))
if mibBuilder.loadTexts: teMIB.setLastUpdated('200501040000Z')
if mibBuilder.loadTexts: teMIB.setOrganization('IETF Traffic Engineering Working Group')
if mibBuilder.loadTexts: teMIB.setContactInfo('\n                  Editor:         Kireeti Kompella\n                          Postal: Juniper Networks, Inc.\n                                  1194 Mathilda Ave\n\n\n\n                                  Sunnyvale, CA 94089\n                          Tel:    +1 408 745 2000\n                          E-mail: kireeti@juniper.net\n\n                  The IETF Traffic Engineering Working Group is\n                  chaired by Jim Boyle and Ed Kern.\n\n                  WG Mailing List information:\n\n                    General Discussion: te-wg@ops.ietf.org\n                      To Subscribe:     te-wg-request@ops.ietf.org\n                         In Body:       subscribe\n                      Archive:          ftp://ops.ietf.org/pub/lists\n\n                  Comments on the MIB module should be sent to the\n                  mailing list.  The archives for this mailing list\n                  should be consulted for previous discussion on\n                  this MIB.\n                 ')
if mibBuilder.loadTexts: teMIB.setDescription('The Traffic Engineering MIB module.\n\n                  Copyright (C) The Internet Society (2005).  This\n                  version of this MIB module is part of RFC 3970;\n                  see the RFC itself for full legal notices.\n                 ')
teMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 0))
teMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 1))
teMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 2))
teInfo = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 1, 1))
teDistProtocol = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 1), Bits().clone(namedValues=NamedValues(("other", 0), ("isis", 1), ("ospf", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: teDistProtocol.setDescription('IGP used to distribute Traffic Engineering\n                 information and topology to each device for the\n                 purpose of automatic path computation.  More than\n                 one IGP may be used to distribute TE information.\n                ')
teSignalingProto = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 2), Bits().clone(namedValues=NamedValues(("other", 0), ("rsvpte", 1), ("crldp", 2), ("static", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: teSignalingProto.setDescription('Traffic Engineering signaling protocols supported\n                 by this device.  More than one protocol may be\n                 supported.\n                ')
teNotificationEnable = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 3), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: teNotificationEnable.setDescription('If this object is true, then it enables the\n                 generation of notifications from this MIB module.\n                 Otherwise notifications are not generated.\n                ')
teNextTunnelIndex = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teNextTunnelIndex.setDescription('An integer that may be used as a new Index in the\n\n\n\n                 teTunnelTable.\n\n                 The special value of 0 indicates that no more new\n                 entries can be created in that table.\n\n                 When this MIB module is used for configuration, this\n                 object always contains a legal value (if non-zero)\n                 for an index that is not currently used in that\n                 table.  The Command Generator (Network Management\n                 Application) reads this variable and uses the\n                 (non-zero) value read when creating a new row with\n                 an SNMP SET.  When the SET is performed, the Command\n                 Responder (agent) must determine whether the value\n                 is indeed still unused; Two Network Management\n                 Applications may attempt to create a row\n                 (configuration entry) simultaneously and use the\n                 same value.  If it is currently unused, the SET\n                 succeeds, and the Command Responder (agent) changes\n                 the value of this object according to an\n                 implementation-specific algorithm.  If the value is\n                 in use, however, the SET fails.  The Network\n                 Management Application must then re-read this\n                 variable to obtain a new usable value.\n                ')
teNextPathHopIndex = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teNextPathHopIndex.setDescription('An integer that may be used as a new Index in the\n                 tePathHopTable.\n\n                 The special value of 0 indicates that no more new\n                 entries can be created in that table.\n\n                 When this MIB module is used for configuration, this\n                 object always contains a legal value (if non-zero)\n                 for an index that is not currently used in that\n                 table.  The Command Generator (Network Management\n                 Application) reads this variable and uses the\n                 (non-zero) value read when creating a new row with\n                 an SNMP SET.  When the SET is performed, the Command\n                 Responder (agent) must determine whether the value\n                 is indeed still unused; Two Network Management\n                 Applications may attempt to create a row\n                 (configuration entry) simultaneously and use the\n                 same value.  If it is currently unused, the SET\n\n\n\n                 succeeds, and the Command Responder (agent) changes\n                 the value of this object according to an\n                 implementation-specific algorithm.  If the value is\n                 in use, however, the SET fails.  The Network\n                 Management Application must then re-read this\n                 variable to obtain a new usable value.\n                ')
teConfiguredTunnels = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teConfiguredTunnels.setDescription('Number of currently configured Tunnels.')
teActiveTunnels = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teActiveTunnels.setDescription('Number of currently active Tunnels.')
tePrimaryTunnels = MibScalar((1, 3, 6, 1, 2, 1, 122, 1, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tePrimaryTunnels.setDescription('Number of currently active Tunnels running on\n                 their primary paths.\n                ')
teAdminGroupTable = MibTable((1, 3, 6, 1, 2, 1, 122, 1, 1, 9), )
if mibBuilder.loadTexts: teAdminGroupTable.setDescription('A mapping of configured administrative groups.  Each\n                 entry represents an Administrative Group and\n                 provides a name and index for the group.\n                 Administrative groups are used to label links in the\n                 Traffic Engineering topology in order to place\n                 constraints (include and exclude) on Tunnel paths.\n\n                 A groupName can only be linked to one group number.\n                 The groupNumber is the number assigned to the\n                 administrative group used in constraints,\n                 such as tePathIncludeAny or tePathIncludeAll.\n                ')
teAdminGroupEntry = MibTableRow((1, 3, 6, 1, 2, 1, 122, 1, 1, 9, 1), ).setIndexNames((0, "TE-MIB", "teAdminGroupNumber"))
if mibBuilder.loadTexts: teAdminGroupEntry.setDescription('A mapping between a configured group number and\n                 its human-readable name.  The group number should\n                 be between 1 and 32, inclusive.  Group number n\n                 represents bit number (n-1) in the bit vector for\n                 Include/Exclude constraints.\n\n                 All entries in this table MUST be kept in stable\n                 storage so that they will re-appear in case of a\n                 restart/reboot.\n                ')
teAdminGroupNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 1, 9, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,32)))
if mibBuilder.loadTexts: teAdminGroupNumber.setDescription('Index of the administrative group.')
teAdminGroupName = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 1, 9, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teAdminGroupName.setDescription('Name of the administrative group.')
teAdminGroupRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 1, 9, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teAdminGroupRowStatus.setDescription('The status of this conceptual row.\n\n                 The value of this object has no effect on whether\n                 other objects in this conceptual row can be\n\n\n\n                 modified.\n                ')
teTunnelTable = MibTable((1, 3, 6, 1, 2, 1, 122, 1, 2), )
if mibBuilder.loadTexts: teTunnelTable.setDescription('Table of Configured Traffic Tunnels.')
teTunnelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 122, 1, 2, 1), ).setIndexNames((0, "TE-MIB", "teTunnelIndex"))
if mibBuilder.loadTexts: teTunnelEntry.setDescription('Entry containing information about a particular\n                 Traffic Tunnel.\n                ')
teTunnelIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: teTunnelIndex.setDescription('A unique index that identifies a Tunnel.  If the TE\n                 Tunnel is considered an interface, then this index\n                 must match the interface index of the corresponding\n                 interface.  Otherwise, this index must be at least\n                 2^24, so that it does not overlap with any existing\n                 interface index.\n                ')
teTunnelName = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelName.setDescription("Name of the Traffic Tunnel.\n\n                 Note that the name of a Tunnel MUST be unique.\n                 When a SET request contains a name that is already\n                 in use for another entry, then the implementation\n                 must return an inconsistentValue error.\n\n                 The value of this object cannot be changed if the\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
teTunnelNextPathIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelNextPathIndex.setDescription('An integer that may be used as a new Index for the\n                 next Path in this Tunnel.\n\n                 The special value of 0 indicates that no more Paths\n                 can be created for this Tunnel, or that no more new\n                 entries can be created in tePathTable.\n\n\n\n\n                 When this MIB module is used for configuration, this\n                 object always contains a legal value (if non-zero)\n                 for an index that is not currently used in that\n                 table.  The Command Generator (Network Management\n                 Application) reads this variable and uses the\n                 (non-zero) value read when creating a new row with\n                 an SNMP SET.  When the SET is performed, the Command\n                 Responder (agent) must determine whether the value\n                 is indeed still unused; Two Network Management\n                 Applications may attempt to create a row\n                 (configuration entry) simultaneously and use the\n                 same value.  If it is currently unused, the SET\n                 succeeds, and the Command Responder (agent) changes\n                 the value of this object according to an\n                 implementation-specific algorithm.  If the value is\n                 in use, however, the SET fails.  The Network\n                 Management Application must then re-read this\n                 variable to obtain a new usable value.\n                ')
teTunnelRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelRowStatus.setDescription("The status of this conceptual row.\n\n                 When the value of this object is 'active', then\n                 the values for the corresponding objects\n                 teTunnelName, teTunnelSourceAddressType,\n                 teTunnelSourceAddress,\n                 teTunnelDestinationAddressType, and\n                 teTunnelDestinationAddress cannot be changed.\n                ")
teTunnelStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 5), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelStorageType.setDescription("The storage type for this conceptual row.\n\n                 Conceptual rows having the value 'permanent' need\n                 not allow write-access to any columnar objects\n                 in the row.\n                ")
teTunnelSourceAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 6), TeHopAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelSourceAddressType.setDescription("The type of Traffic Engineered Tunnel hop address\n                 for the source of this Tunnel.  Typically, this\n                 address type is IPv4 or IPv6, with a prefix length\n                 of 32 or 128, respectively.  If the TE Tunnel path\n                 is being computed by a path computation server,\n                 however, it is possible to use more flexible source\n                 address types, such as AS numbers or prefix lengths\n                 less than host address lengths.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
teTunnelSourceAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 7), TeHopAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelSourceAddress.setDescription("The Source Traffic Engineered Tunnel hop address of\n                 this Tunnel.\n\n                 The type of this address is determined by the value\n                 of the corresponding teTunnelSourceAddressType.\n\n                 Note that the source and destination addresses of a\n                 Tunnel can be different address types.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
teTunnelDestinationAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 8), TeHopAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelDestinationAddressType.setDescription("The type of Traffic Engineered Tunnel hop address\n                 for the destination of this Tunnel.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n\n\n\n                ")
teTunnelDestinationAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 9), TeHopAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teTunnelDestinationAddress.setDescription("The Destination Traffic Engineered Tunnel hop\n                 address of this Tunnel.\n\n                 The type of this address is determined by the value\n                 of the corresponding teTunnelDestinationAddressType.\n\n                 Note that source and destination addresses of a\n                 Tunnel can be different address types.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
teTunnelState = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("up", 2), ("down", 3), ("testing", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelState.setDescription('The operational state of the Tunnel.')
teTunnelDiscontinuityTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 11), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelDiscontinuityTimer.setDescription("The value of sysUpTime on the most recent occasion\n                 at which any one or more of this tunnel's counters\n                 suffered a discontinuity.  The relevant counters\n                 are teTunnelOctets, teTunnelPackets,\n                 teTunnelLPOctets, and teTunnelLPPackets.  If no such\n                 discontinuities have occurred since the last\n                 re-initialization of the local management subsystem\n                 then this object contains a zero value.\n                ")
teTunnelOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 12), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelOctets.setDescription('The number of octets that have been forwarded over\n                 the Tunnel.\n\n                 Discontinuities in the value of this counter can\n                 occur at re-initialization of the management system,\n                 and at other times, as indicated by the value of\n                 teTunnelDiscontinuityTimer.\n                ')
teTunnelPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 13), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelPackets.setDescription('The number of packets that have been forwarded over\n                 the Tunnel.\n\n                 Discontinuities in the value of this counter can\n                 occur at re-initialization of the management system\n                 and at other times, as indicated by the value of\n                 teTunnelDiscontinuityTimer.\n                ')
teTunnelLPOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelLPOctets.setDescription('The number of octets that have been forwarded over\n                 the Tunnel.\n\n                 Discontinuities in the value of this counter can\n                 occur at re-initialization of the management system\n                 and at other times, as indicated by the value of\n                 teTunnelDiscontinuityTimer.\n                ')
teTunnelLPPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelLPPackets.setDescription('The number of packets that have been forwarded over\n                 the Tunnel.\n\n\n\n                 Discontinuities in the value of this counter can\n                 occur at re-initialization of the management system\n                 and at other times, as indicated by the value of\n                 teTunnelDiscontinuityTimer.\n                ')
teTunnelAge = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 16), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelAge.setDescription('The age (i.e., time from creation of this conceptual\n                 row till now) of this Tunnel in hundredths of a\n                 second.  Note that because TimeTicks wrap in about\n                 16 months, this value is best used in interval\n                 measurements.\n                ')
teTunnelTimeUp = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 17), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelTimeUp.setDescription('The total time in hundredths of a second that this\n                 Tunnel has been operational.  Note that because\n                 TimeTicks wrap in about 16 months, this value is\n                 best used in interval measurements.\n\n                 An example of usage of this object would be to\n                 compute the percentage up time over a period of time\n                 by obtaining values of teTunnelAge and\n                 teTunnelTimeUp at two points in time and computing\n                 the following ratio:\n                 ((teTunnelTimeUp2 - teTunnelTimeUp1)/\n                 (teTunnelAge2 - teTunnelAge1)) * 100 %.  In doing\n                 so, the management station must account for\n                 wrapping of the values of teTunnelAge and\n                 teTunnelTimeUp between the two measurements.\n                ')
teTunnelPrimaryTimeUp = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 18), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelPrimaryTimeUp.setDescription("The total time in hundredths of a second that this\n                 Tunnel's primary path has been operational.  Note\n                 that because TimeTicks wrap in about 16 months, this\n\n\n\n                 value is best used in interval measurements.\n\n                 An example of usage of this field would be to\n                 compute what percentage of time that a TE Tunnel was\n                 on the primary path over a period of time by\n                 computing\n                 ((teTunnelPrimaryTimeUp2 - teTunnelPrimaryTimeUp1)/\n                 (teTunnelTimeUp2 - teTunnelTimeUp1))*100 %.  In\n                 doing so, the management station must account for\n                 wrapping of the values of teTunnelPrimaryTimeUp and\n                 teTunnelTimeUp between the two measurements.\n                ")
teTunnelTransitions = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelTransitions.setDescription('The number of operational state transitions\n                 (up -> down and down -> up) this Tunnel has\n                 undergone.\n                ')
teTunnelLastTransition = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 20), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelLastTransition.setDescription('The time in hundredths of a second since the last\n                 operational state transition occurred on this\n                 Tunnel.\n\n                 Note that if the last transition was over 16\n                 months ago, this value will be inaccurate.\n                ')
teTunnelPathChanges = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelPathChanges.setDescription('The number of path changes this Tunnel has had.')
teTunnelLastPathChange = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 22), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelLastPathChange.setDescription('The time in hundredths of a second since the last\n                 path change occurred on this Tunnel.\n\n                 Note that if the last transition was over 16\n                 months ago, this value will be inaccurate.\n\n                 Path changes may be caused by network events or by\n                 reconfiguration that affects the path.\n                ')
teTunnelConfiguredPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 23), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelConfiguredPaths.setDescription('The number of paths configured for this Tunnel.')
teTunnelStandbyPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 24), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelStandbyPaths.setDescription('The number of standby paths configured for this\n                 Tunnel.\n                ')
teTunnelOperationalPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 2, 1, 25), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: teTunnelOperationalPaths.setDescription('The number of operational paths for this Tunnel.\n                 This includes the path currently active, as\n                 well as operational standby paths.\n                ')
tePathTable = MibTable((1, 3, 6, 1, 2, 1, 122, 1, 3), )
if mibBuilder.loadTexts: tePathTable.setDescription('Table of Configured Traffic Tunnels.')
tePathEntry = MibTableRow((1, 3, 6, 1, 2, 1, 122, 1, 3, 1), ).setIndexNames((0, "TE-MIB", "teTunnelIndex"), (0, "TE-MIB", "tePathIndex"))
if mibBuilder.loadTexts: tePathEntry.setDescription('Entry containing information about a particular\n                 Traffic Tunnel.  Each Traffic Tunnel can have zero\n                 or more Traffic Paths.\n\n                 As a Traffic Path can only exist over an existing\n                 Traffic Tunnel, all tePathEntries with\n                 a value of n for teTunnelIndex MUST be removed by\n                 the implementation when the corresponding\n                 teTunnelEntry with a value of n for teTunnelIndex\n                 is removed.\n                ')
tePathIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: tePathIndex.setDescription('An index that uniquely identifies a path within\n                 a Tunnel.\n\n\n\n                 The combination of <teTunnelIndex, tePathIndex> thus\n                 uniquely identifies a path among all paths on this\n                 router.\n                ')
tePathName = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathName.setDescription("The name of this path.\n\n                 A pathName must be unique within the set of paths\n                 over a single tunnel.  If a SET request is received\n                 with a duplicate name, then the implementation MUST\n                 return an inconsistentValue error.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
tePathRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathRowStatus.setDescription("The status of this conceptual row.\n\n                 When the value of this object is 'active', then\n                 the value of tePathName cannot be changed.  All\n                 other writable objects may be changed; however,\n                 these changes may affect traffic going over the TE\n                 tunnel or require the path to be computed and/or\n                 re-signaled.\n                ")
tePathStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 4), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathStorageType.setDescription("The storage type for this conceptual row.\n\n                 Conceptual rows having the value 'permanent' need\n                 not allow write-access to any columnar objects\n                 in the row.\n                ")
tePathType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("primary", 2), ("standby", 3), ("secondary", 4),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathType.setDescription('The type for this PathEntry; i.e., whether this path\n                 is a primary path, a standby path, or a secondary\n                 path.\n                ')
tePathConfiguredRoute = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 6), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathConfiguredRoute.setDescription('The route that this TE path is configured to follow;\n                 i.e., an ordered list of hops.  The value of this\n                 object gives the primary index into the Hop Table.\n                 The secondary index is the hop count in the path, so\n                 to get the route, one could get the first hop with\n                 index <tePathConfiguredRoute, 1> in the Hop Table\n                 and do a getnext to get subsequent hops.\n                ')
tePathBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 7), MplsBitRate()).setUnits('Kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathBandwidth.setDescription('The configured bandwidth for this Tunnel,\n                 in units of thousands of bits per second (Kbps).\n                ')
tePathIncludeAny = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 8), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathIncludeAny.setDescription('This is a configured set of administrative groups\n                 specified as a bit vector (i.e., bit n is 1 if group\n\n\n\n                 n is in the set, where n = 0 is the LSB).  For each\n                 link that this path goes through, the link must have\n                 at least one of the groups specified in IncludeAny\n                 to be acceptable.  If IncludeAny is zero, all links\n                 are acceptable.\n                ')
tePathIncludeAll = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 9), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathIncludeAll.setDescription('This is a configured set of administrative groups\n                 specified as a bit vector (i.e., bit n is 1 if group\n                 n is in the set, where n = 0 is the LSB).  For each\n                 link that this path goes through, the link must have\n                 all of the groups specified in IncludeAll to be\n                 acceptable.  If IncludeAll is zero, all links are\n                 acceptable.\n                ')
tePathExclude = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 10), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathExclude.setDescription("This is a configured set of administrative groups\n                 specified as a bit vector (i.e., bit n is 1 if group\n                 n is in the set, where n = 0 is the LSB).  For each\n                 link that this path goes through, the link MUST have\n                 groups associated with it, and the intersection of\n                 the link's groups and the 'exclude' set MUST be\n                 null.\n                ")
tePathSetupPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7)).clone(7)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathSetupPriority.setDescription('The setup priority configured for this path, with 0\n                 as the highest priority and 7 as the lowest.\n                ')
tePathHoldPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathHoldPriority.setDescription('The hold priority configured for this path, with 0\n                 as the highest priority and 7 as the lowest.\n                ')
tePathProperties = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 13), Bits().clone(namedValues=NamedValues(("recordRoute", 0), ("cspf", 1), ("makeBeforeBreak", 2), ("mergeable", 3), ("fastReroute", 4), ("protected", 5),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathProperties.setDescription("The set of configured properties for this path,\n                 expressed as a bit map.  For example, if the path\n                 supports 'make before break', then bit 2 is set.\n                ")
tePathOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("unknown", 0), ("down", 1), ("testing", 2), ("dormant", 3), ("ready", 4), ("operational", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tePathOperStatus.setDescription('The operational status of the path:\n                 unknown:\n                 down:        Signaling failed.\n                 testing:     Administratively set aside for testing.\n                 dormant:     Not signaled (for a backup tunnel).\n                 ready:       Signaled but not yet carrying traffic.\n                 operational: Signaled and carrying traffic.\n                ')
tePathAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("normal", 1), ("testing", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathAdminStatus.setDescription('The operational status of the path:\n                 normal:      Used normally for forwarding.\n                 testing:     Administratively set aside for testing.\n                ')
tePathComputedRoute = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 16), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tePathComputedRoute.setDescription('The route computed for this path, perhaps using\n                 some form of Constraint-based Routing.  The\n                 algorithm is implementation dependent.\n\n                 This object returns the computed route as an ordered\n                 list of hops.  The value of this object gives the\n                 primary index into the Hop Table.  The secondary\n                 index is the hop count in the path, so to get the\n                 route, one could get the first hop with index\n                 <tePathComputedRoute, 1> in the Hop Table and do a\n                 getnext to get subsequent hops.\n\n                 A value of zero (0) means there is no computedRoute.\n                ')
tePathRecordedRoute = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 3, 1, 17), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tePathRecordedRoute.setDescription('The route actually used for this path, as recorded\n                 by the signaling protocol.  This is again an ordered\n                 list of hops; each hop is expected to be strict.\n\n                 The value of this object gives the primary index\n                 into the Hop Table.  The secondary index is the hop\n                 count in the path, so to get the route, one can get\n                 the first hop with index <tePathRecordedRoute, 1>\n                 in the Hop Table and do a getnext to get subsequent\n\n\n\n                 hops.\n\n                 A value of zero (0) means there is no recordedRoute.\n                ')
tePathHopTable = MibTable((1, 3, 6, 1, 2, 1, 122, 1, 4), )
if mibBuilder.loadTexts: tePathHopTable.setDescription('Table of Tunnel Path Hops.')
tePathHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 122, 1, 4, 1), ).setIndexNames((0, "TE-MIB", "teHopListIndex"), (0, "TE-MIB", "tePathHopIndex"))
if mibBuilder.loadTexts: tePathHopEntry.setDescription('Entry containing information about a particular\n                 hop.\n                ')
teHopListIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: teHopListIndex.setDescription('An index that identifies a list of hops.  This is\n                 the primary index to access hops.\n                ')
tePathHopIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: tePathHopIndex.setDescription('An index that identifies a particular hop among the\n                 list of hops for a path.  An index of i identifies\n                 the ith hop.  This is the secondary index for a hop\n                 entry.\n                ')
tePathHopRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathHopRowStatus.setDescription("The status of this conceptual row.\n\n                 Any field in this table can be changed, even if the\n                 value of this object is 'active'.  However, such a\n                 change may cause traffic to be rerouted or even\n                 disrupted.\n                ")
tePathHopStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 4), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathHopStorageType.setDescription("The storage type for this conceptual row.\n\n                 Conceptual rows having the value 'permanent' need\n                 not allow write-access to any columnar objects\n                 in the row.\n                ")
tePathHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 5), TeHopAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathHopAddrType.setDescription("The type of Traffic Engineered Tunnel hop Address\n                 of this hop.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding tePathRowStatus\n                 object is 'active'.\n                ")
tePathHopAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 6), TeHopAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: tePathHopAddress.setDescription("The Traffic Engineered Tunnel hop Address of this\n                 hop.\n\n                 The type of this address is determined by the value\n                 of the corresponding tePathHopAddressType.\n\n                 The value of this object cannot be changed\n                 if the value of the corresponding teTunnelRowStatus\n                 object is 'active'.\n                ")
tePathHopType = MibTableColumn((1, 3, 6, 1, 2, 1, 122, 1, 4, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2,))).clone(namedValues=NamedValues(("unknown", 0), ("loose", 1), ("strict", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tePathHopType.setDescription('The type of hop:\n                 unknown:\n                 loose:    This hop is a LOOSE hop.\n                 strict:   This hop is a STRICT hop.\n                ')
teTunnelUp = NotificationType((1, 3, 6, 1, 2, 1, 122, 0, 1)).setObjects(*(("TE-MIB", "teTunnelName"), ("TE-MIB", "tePathName"),))
if mibBuilder.loadTexts: teTunnelUp.setDescription("A teTunnelUp notification is generated when the\n                 Tunnel indexed by teTunnelName transitions to the\n                 'up' state.\n\n                 A tunnel is up when at least one of its paths is up.\n                 The tePathName is the name of the path whose\n                 transition to up made the tunnel go up.\n\n\n\n\n                 This notification MUST be limited to at most one\n                 every minute, in case the tunnel flaps up and down.\n                ")
teTunnelDown = NotificationType((1, 3, 6, 1, 2, 1, 122, 0, 2)).setObjects(*(("TE-MIB", "teTunnelName"), ("TE-MIB", "tePathName"),))
if mibBuilder.loadTexts: teTunnelDown.setDescription("A teTunnelDown notification is generated when the\n                 Tunnel indexed by teTunnelName transitions to the\n                 'down' state.\n\n                 A tunnel is up when at least one of its paths is up.\n                 The tePathName is the name of the path whose\n                 transition to down made the tunnel go down.\n\n                 This notification MUST be limited to at most one\n                 every minute, in case the tunnel flaps up and down.\n                ")
teTunnelChanged = NotificationType((1, 3, 6, 1, 2, 1, 122, 0, 3)).setObjects(*(("TE-MIB", "teTunnelName"), ("TE-MIB", "tePathName"),))
if mibBuilder.loadTexts: teTunnelChanged.setDescription('A teTunnelChanged notification is generated when an\n                 active path on the Tunnel indexed by teTunnelName\n                 changes or a new path becomes active.  The value\n                 of tePathName is the new active path.\n\n                 This notification MUST be limited to at most one\n                 every minute, in case the tunnel changes quickly.\n                ')
teTunnelRerouted = NotificationType((1, 3, 6, 1, 2, 1, 122, 0, 4)).setObjects(*(("TE-MIB", "teTunnelName"), ("TE-MIB", "tePathName"),))
if mibBuilder.loadTexts: teTunnelRerouted.setDescription('A teTunnelRerouted notification is generated when\n                 an active path for the Tunnel indexed by\n                 teTunnelName stays the same, but its route changes.\n\n                 This notification MUST be limited to at most one\n                 every minute, in case the tunnel reroutes quickly.\n                ')
teGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 2, 1))
teModuleCompliance = MibIdentifier((1, 3, 6, 1, 2, 1, 122, 2, 2))
teTrafficEngineeringGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 122, 2, 1, 1)).setObjects(*(("TE-MIB", "teTunnelName"), ("TE-MIB", "teTunnelNextPathIndex"), ("TE-MIB", "teTunnelRowStatus"), ("TE-MIB", "teTunnelStorageType"), ("TE-MIB", "teTunnelSourceAddressType"), ("TE-MIB", "teTunnelSourceAddress"), ("TE-MIB", "teTunnelDestinationAddressType"), ("TE-MIB", "teTunnelDestinationAddress"), ("TE-MIB", "teTunnelState"), ("TE-MIB", "teTunnelDiscontinuityTimer"), ("TE-MIB", "teTunnelOctets"), ("TE-MIB", "teTunnelPackets"), ("TE-MIB", "teTunnelLPOctets"), ("TE-MIB", "teTunnelLPPackets"), ("TE-MIB", "teTunnelAge"), ("TE-MIB", "teTunnelTimeUp"), ("TE-MIB", "teTunnelPrimaryTimeUp"), ("TE-MIB", "teTunnelTransitions"), ("TE-MIB", "teTunnelLastTransition"), ("TE-MIB", "teTunnelPathChanges"), ("TE-MIB", "teTunnelLastPathChange"), ("TE-MIB", "teTunnelConfiguredPaths"), ("TE-MIB", "teTunnelStandbyPaths"), ("TE-MIB", "teTunnelOperationalPaths"), ("TE-MIB", "tePathBandwidth"), ("TE-MIB", "tePathIncludeAny"), ("TE-MIB", "tePathIncludeAll"), ("TE-MIB", "tePathExclude"), ("TE-MIB", "tePathSetupPriority"), ("TE-MIB", "tePathHoldPriority"), ("TE-MIB", "tePathProperties"), ("TE-MIB", "tePathOperStatus"), ("TE-MIB", "tePathAdminStatus"), ("TE-MIB", "tePathComputedRoute"), ("TE-MIB", "tePathRecordedRoute"), ("TE-MIB", "teDistProtocol"), ("TE-MIB", "teSignalingProto"), ("TE-MIB", "teNotificationEnable"), ("TE-MIB", "teNextTunnelIndex"), ("TE-MIB", "teNextPathHopIndex"), ("TE-MIB", "teAdminGroupName"), ("TE-MIB", "teAdminGroupRowStatus"), ("TE-MIB", "teConfiguredTunnels"), ("TE-MIB", "teActiveTunnels"), ("TE-MIB", "tePrimaryTunnels"), ("TE-MIB", "tePathName"), ("TE-MIB", "tePathType"), ("TE-MIB", "tePathRowStatus"), ("TE-MIB", "tePathStorageType"), ("TE-MIB", "tePathConfiguredRoute"), ("TE-MIB", "tePathHopRowStatus"), ("TE-MIB", "tePathHopStorageType"), ("TE-MIB", "tePathHopAddrType"), ("TE-MIB", "tePathHopAddress"), ("TE-MIB", "tePathHopType"),))
if mibBuilder.loadTexts: teTrafficEngineeringGroup.setDescription('Objects for Traffic Engineering in this MIB module.')
teNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 122, 2, 1, 2)).setObjects(*(("TE-MIB", "teTunnelUp"), ("TE-MIB", "teTunnelDown"), ("TE-MIB", "teTunnelChanged"), ("TE-MIB", "teTunnelRerouted"),))
if mibBuilder.loadTexts: teNotificationGroup.setDescription('Notifications specified in this MIB module.')
teModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 122, 2, 2, 1)).setObjects(*(("TE-MIB", "teTrafficEngineeringGroup"), ("TE-MIB", "teNotificationGroup"),))
if mibBuilder.loadTexts: teModuleReadOnlyCompliance.setDescription('When this MIB module is implemented without support\n                 for read-create (i.e., in read-only mode), then such\n                 an implementation can claim read-only compliance.\n                 Such a device can be monitored but cannot be\n                 configured with this MIB module.\n                ')
teModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 122, 2, 2, 2)).setObjects(*(("TE-MIB", "teTrafficEngineeringGroup"), ("TE-MIB", "teNotificationGroup"),))
if mibBuilder.loadTexts: teModuleFullCompliance.setDescription('When this MIB module is implemented with support for\n                 read-create, then the implementation can claim\n                 full compliance.  Such devices can be both\n\n\n\n                 monitored and configured with this MIB module.\n                ')
teModuleServerReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 122, 2, 2, 3)).setObjects(*(("TE-MIB", "teTrafficEngineeringGroup"), ("TE-MIB", "teNotificationGroup"),))
if mibBuilder.loadTexts: teModuleServerReadOnlyCompliance.setDescription('When this MIB module is implemented by a path\n                 computation server without support for read-create\n                 (i.e., in read-only mode), then the implementation\n                 can claim read-only compliance.  Such\n                 a device can be monitored but cannot be\n                 configured with this MIB module.\n                ')
teModuleServerFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 122, 2, 2, 4)).setObjects(*(("TE-MIB", "teTrafficEngineeringGroup"), ("TE-MIB", "teNotificationGroup"),))
if mibBuilder.loadTexts: teModuleServerFullCompliance.setDescription('When this MIB module is implemented by a path\n                 computation server with support for read-create,\n                 then the implementation can claim full\n                 compliance.\n                ')
mibBuilder.exportSymbols("TE-MIB", teMIBObjects=teMIBObjects, teTunnelPrimaryTimeUp=teTunnelPrimaryTimeUp, tePathComputedRoute=tePathComputedRoute, teMIBNotifications=teMIBNotifications, teTunnelTimeUp=teTunnelTimeUp, teTunnelStandbyPaths=teTunnelStandbyPaths, teTunnelDestinationAddressType=teTunnelDestinationAddressType, tePathHopAddrType=tePathHopAddrType, tePathEntry=tePathEntry, tePathSetupPriority=tePathSetupPriority, tePathHoldPriority=tePathHoldPriority, teTunnelPackets=teTunnelPackets, teSignalingProto=teSignalingProto, teTunnelState=teTunnelState, teTunnelEntry=teTunnelEntry, teTunnelLPOctets=teTunnelLPOctets, tePathStorageType=tePathStorageType, tePathType=tePathType, tePathHopIndex=tePathHopIndex, teTunnelPathChanges=teTunnelPathChanges, teModuleServerFullCompliance=teModuleServerFullCompliance, tePathHopAddress=tePathHopAddress, teTunnelLastTransition=teTunnelLastTransition, tePathTable=tePathTable, teTunnelLastPathChange=teTunnelLastPathChange, teMIBConformance=teMIBConformance, teTunnelLPPackets=teTunnelLPPackets, teTunnelIndex=teTunnelIndex, teTunnelAge=teTunnelAge, teTunnelConfiguredPaths=teTunnelConfiguredPaths, teAdminGroupTable=teAdminGroupTable, teTunnelTransitions=teTunnelTransitions, teTunnelTable=teTunnelTable, tePathHopRowStatus=tePathHopRowStatus, tePrimaryTunnels=tePrimaryTunnels, teTunnelOctets=teTunnelOctets, tePathName=tePathName, PYSNMP_MODULE_ID=teMIB, teNotificationGroup=teNotificationGroup, teTrafficEngineeringGroup=teTrafficEngineeringGroup, teTunnelSourceAddress=teTunnelSourceAddress, teTunnelSourceAddressType=teTunnelSourceAddressType, teGroups=teGroups, teTunnelUp=teTunnelUp, teActiveTunnels=teActiveTunnels, tePathHopTable=tePathHopTable, tePathHopType=tePathHopType, tePathProperties=tePathProperties, teTunnelDestinationAddress=teTunnelDestinationAddress, teInfo=teInfo, teModuleServerReadOnlyCompliance=teModuleServerReadOnlyCompliance, teHopListIndex=teHopListIndex, teAdminGroupNumber=teAdminGroupNumber, teTunnelStorageType=teTunnelStorageType, teModuleCompliance=teModuleCompliance, tePathHopEntry=tePathHopEntry, teAdminGroupEntry=teAdminGroupEntry, tePathAdminStatus=tePathAdminStatus, teNextPathHopIndex=teNextPathHopIndex, teMIB=teMIB, teModuleReadOnlyCompliance=teModuleReadOnlyCompliance, teAdminGroupRowStatus=teAdminGroupRowStatus, teTunnelRowStatus=teTunnelRowStatus, teTunnelNextPathIndex=teTunnelNextPathIndex, tePathIncludeAny=tePathIncludeAny, tePathIndex=tePathIndex, tePathExclude=tePathExclude, teDistProtocol=teDistProtocol, teNotificationEnable=teNotificationEnable, tePathOperStatus=tePathOperStatus, tePathRecordedRoute=tePathRecordedRoute, teAdminGroupName=teAdminGroupName, tePathRowStatus=tePathRowStatus, teConfiguredTunnels=teConfiguredTunnels, tePathIncludeAll=tePathIncludeAll, teModuleFullCompliance=teModuleFullCompliance, teTunnelDiscontinuityTimer=teTunnelDiscontinuityTimer, teTunnelOperationalPaths=teTunnelOperationalPaths, teTunnelChanged=teTunnelChanged, teTunnelDown=teTunnelDown, tePathHopStorageType=tePathHopStorageType, teTunnelName=teTunnelName, teNextTunnelIndex=teNextTunnelIndex, teTunnelRerouted=teTunnelRerouted, tePathBandwidth=tePathBandwidth, tePathConfiguredRoute=tePathConfiguredRoute)



#
# PySNMP MIB module SNMPv2-TC-v1 (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SNMPv2-TC-v1
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:56 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( NotificationType, Integer32, MibIdentifier, Counter64, iso, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, ModuleIdentity, IpAddress, Bits, Unsigned32, ObjectIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "Integer32", "MibIdentifier", "Counter64", "iso", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "ModuleIdentity", "IpAddress", "Bits", "Unsigned32", "ObjectIdentity", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
class DisplayString(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class PhysAddress(OctetString):
    pass

class MacAddress(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(6,6)
    fixedLength = 6

class TruthValue(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("true", 1), ("false", 2),)

class TestAndIncr(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class AutonomousType(ObjectIdentifier):
    pass

class InstancePointer(ObjectIdentifier):
    pass

class VariablePointer(ObjectIdentifier):
    pass

class RowPointer(ObjectIdentifier):
    pass

class RowStatus(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("active", 1), ("notInService", 2), ("notReady", 3), ("createAndGo", 4), ("createAndWait", 5), ("destroy", 6),)

class TimeStamp(TimeTicks):
    pass

class TimeInterval(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class DateAndTime(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(11,11)
    fixedLength = 11

class StorageType(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("other", 1), ("volatile", 2), ("nonVolatile", 3), ("permanent", 4), ("readOnly", 5),)

class TDomain(ObjectIdentifier):
    pass

class TAddress(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,255)

mibBuilder.exportSymbols("SNMPv2-TC-v1", TDomain=TDomain, VariablePointer=VariablePointer, InstancePointer=InstancePointer, StorageType=StorageType, PhysAddress=PhysAddress, TestAndIncr=TestAndIncr, AutonomousType=AutonomousType, TimeStamp=TimeStamp, RowPointer=RowPointer, TAddress=TAddress, DateAndTime=DateAndTime, RowStatus=RowStatus, MacAddress=MacAddress, DisplayString=DisplayString, TimeInterval=TimeInterval, TruthValue=TruthValue)
